Cython: __about__.py

Generated by Cython 3.0.2

Yellow lines hint at Python interaction.
Click on a line that starts with a "`+`" to see the C code that Cython generated for it.

Raw output: __about__.c

    +1: # SPDX-FileCopyrightText: 2023-present joshua-auchincloss <joshua.auchincloss@proton.me>

      __pyx_t_2 = __Pyx_PyDict_NewPresized(0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      if (PyDict_SetItem(__pyx_d, __pyx_n_s_test, __pyx_t_2) < 0) __PYX_ERR(0, 1, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

     2: #

     3: # SPDX-License-Identifier: MIT

    +4: __version__ = "0.0.1"

      if (PyDict_SetItem(__pyx_d, __pyx_n_s_version, __pyx_kp_u_0_0_1) < 0) __PYX_ERR(0, 4, __pyx_L1_error)